@@ -405,7 +405,7 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
                     value.sort(key=sort)
 
                 # Add to list
-                cmaps_list.append(key)
+                cmaps_list.append((key, False))
                 cmaps_list.extend(value)
 
     # Else, a list is used
@@ -423,47 +423,54 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
         if sort is not None:
             cmaps_list.sort(key=sort)
 
+    # Add title to cmaps_list if requested
+    if title:
+        cmaps_list.insert(0, (title, True))
+
     # Obtain the colorspace converter for showing cmaps in grey-scale
     cspace_convert = cspace_converter("sRGB1", "CAM02-UCS")
 
     # Create figure instance
-    height = 0.4*(len(cmaps_list)+bool(title))
+    height = 0.4*len(cmaps_list)+0.1
     fig, axs = plt.subplots(figsize=(6.4, height), nrows=len(cmaps_list),
                             ncols=2)
 
-    # Add title if requested and adjust subplot positioning
-    if title:
-        fig.subplots_adjust(top=(1-0.288/height), bottom=0.048/height,
-                            left=0.2, right=0.99, wspace=0.05)
-        fig.suptitle(title, fontsize=16, x=0.595, y=1.0-0.048/height)
-    else:
-        fig.subplots_adjust(top=(1-0.048/height), bottom=0.048/height,
-                            left=0.2, right=0.99, wspace=0.05)
+    # Adjust subplot positioning
+    fig.subplots_adjust(top=(1-0.05/height), bottom=0.05/height, left=0.2,
+                        right=0.99, wspace=0.05)
 
     # If cmaps_list only has a single element, make sure axs is a list
     if(len(cmaps_list) == 1):
         axs = [axs]
 
-    # Set the current cm_type to None
-    cm_type = None
-
     # Loop over all cmaps defined in cmaps list
     for (ax0, ax1), cmap in zip(axs, cmaps_list):
         # Turn axes off
         ax0.set_axis_off()
         ax1.set_axis_off()
 
-        # If cmap is a string, it defines a cm_type
-        if isinstance(cmap, str):
-            # Write the cm_type as text in the correct position
-            fig.text(0.595, ax0.get_position().bounds[1], cmap,
-                     va='bottom', ha='center', fontsize=14)
+        # Obtain position bbox of ax0
+        pos0 = ax0.get_position()
 
-            # Save what the current cm_type is
-            cm_type = cmap
+        # If cmap is a tuple, it defines a title or cm_type
+        if isinstance(cmap, tuple):
+            # If it is a title
+            if cmap[1]:
+                # Write the title as text in the correct position
+                fig.text(0.595, pos0.y0+pos0.height/2, cmap[0],
+                         va='center', ha='center', fontsize=18)
+
+            # If it is a cm_type
+            else:
+                # Write the cm_type as text in the correct position
+                fig.text(0.595, pos0.y0, cmap[0],
+                         va='bottom', ha='center', fontsize=14)
 
         # Else, this is a colormap
         else:
+            # Obtain the colormap type
+            cm_type = get_cmap_type(cmap)
+
             # Get array of all values for which a colormap value is requested
             x = np.arange(cmap.N)
 
@@ -531,11 +538,10 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
             ax1.imshow(rgb_L[np.newaxis, ...], aspect='auto')
 
             # Plot the name of the colormap as text
-            pos = list(ax0.get_position().bounds)
-            x_text = pos[0]-0.01
-            y_text = pos[1]+pos[3]/2
-            fig.text(x_text, y_text, cmap.name, va='center', ha='right',
-                     fontsize=10)
+            x_text = pos0.x0-0.01
+            y_text = pos0.y0+pos0.height/2
+            fig.text(x_text, y_text, cmap.name,
+                     va='center', ha='right', fontsize=10)
 
     # If savefig is not None, save the figure
     if savefig is not None:
@@ -744,8 +750,8 @@ def import_cmaps(cmap_path):
         Relative or absolute path to a custom colormap file; or directory that
         contains custom colormap files. A colormap file can be a *NumPy* binary
         file ('.npy'); a *viscm* source file ('.jscm'); or any text file.
-        If the file is not a JSCM-file, it must contain the normalized RGB
-        values that define the colormap.
+        If the file is not a JSCM-file, it must contain the normalized; 8-bit;
+        or hexadecimal string RGB values that define the colormap.
 
     Notes
     -----
@@ -835,7 +841,8 @@ def import_cmaps(cmap_path):
 
             # If file is anything else
             else:
-                rgb = np.genfromtxt(cm_file_path, dtype=None, encoding=None)
+                rgb = np.genfromtxt(cm_file_path, dtype=None, comments='//',
+                                    encoding=None)
 
             # Register colormap
             register_cmap(cm_name, rgb)
@@ -870,10 +877,12 @@ def register_cmap(name, data):
     ----------
     name : str
         The name that this colormap must have.
-    data : 2D array_like of {float; int} with shape `(N, 3)`
+    data : 2D array_like of {float; int} with shape `(N, 3)` or 1D array_like \
+        of str with shape `(N, )`
         An array containing the RGB values of all segments in the colormap.
-        If int, the array contains 8-bit RGB values.
         If float, the array contains normalized RGB values.
+        If int, the array contains 8-bit RGB values.
+        If str, the array contains hexadecimal string RGB values.
 
     Note
     ----
@@ -883,15 +892,26 @@ def register_cmap(name, data):
     """
 
     # Convert provided data to a NumPy array
-    cm_data = np.array(data, ndmin=2)
+    cm_data = np.array(data)
 
     # Check the type of the data
-    if issubclass(cm_data.dtype.type, np.integer):
-        # If the values are integers, divide them by 255
-        cm_data = cm_data/255
+    if issubclass(cm_data.dtype.type, str):
+        # If the values are strings, make sure they start with a '#'
+        cm_data = map(lambda x: '#'+x if not x.startswith('#') else x, cm_data)
 
-    # Convert cm_data to a list
-    colorlist = cm_data.tolist()
+        # Convert all values to floats
+        colorlist = list(map(to_rgb, cm_data))
+
+    else:
+        # Make sure that cm_data is 2D
+        cm_data = np.array(cm_data, copy=False, ndmin=2)
+
+        # If the values are integers, divide them by 255
+        if issubclass(cm_data.dtype.type, np.integer):
+            cm_data = cm_data/255
+
+        # Convert cm_data to a list
+        colorlist = cm_data.tolist()
 
     # Transform colorlist into a Colormap
     cmap_N = len(colorlist)
@@ -985,16 +1005,16 @@ def take_cmap_colors(cmap, N, *, cmap_range=(0, 1), return_fmt='float'):
         The normalized value range in the colormap from which colors should be
         taken.
         By default, colors are taken from the entire colormap.
-    return_fmt : {'float'/'norm'; 'str'/'hex'; 'int'/'8bit'}. Default: 'float'
+    return_fmt : {'float'/'norm'; 'int'/'8bit'; 'str'/'hex'}. Default: 'float'
         The format of the requested colors.
         If 'float'/'norm', the colors are returned as normalized RGB tuples.
+        If 'int'/'8bit', the colors are returned as 8-bit RGB tuples.
         If 'str'/'hex', the colors are returned using their hexadecimal string
         representations.
-        If 'int'/'8bit', the colors are returned as 8-bit RGB tuples.
 
     Returns
     -------
-    colors : list of tuple, str
+    colors : list of {tuple; str}
         The colors that were taken from the provided `cmap`.
 
     Examples
